neuroio-python
_________________

[![PyPI version](https://badge.fury.io/py/neuroio-python.svg)](http://badge.fury.io/py/neuroio-python)
[![Build Status](https://travis-ci.org/levchik/neuroio-python.svg?branch=master)](https://travis-ci.org/levchik/neuroio-python)
[![codecov](https://codecov.io/gh/levchik/neuroio-python/branch/master/graph/badge.svg)](https://codecov.io/gh/levchik/neuroio-python)
[![License](https://img.shields.io/github/license/mashape/apistatus.svg)](https://pypi.python.org/pypi/neuroio-python/)
[![Downloads](https://pepy.tech/badge/neuroio-python)](https://pepy.tech/project/neuroio-python)
_________________

[Read Latest Documentation](https://neuroio.github.io/neuroio-python/) - [Browse GitHub Code Repository](https://github.com/neuroio/neuroio-python/)
_________________

**neuroio-python** A Python package for interacting with NeuroIO API
